@@ -13,7 +13,7 @@
 ##############################################################################
 """Test tcpdoc
 
-$Id: tests.py 116404 2010-09-14 14:42:17Z icemac $
+$Id: tests.py 116533 2010-09-17 15:47:35Z icemac $
 """
 from doctest import DocTestSuite
 import os
@@ -31,8 +31,7 @@ from zope.app.publication.requestpublicationfactories import BrowserFactory
 from zope.app.testing import functional
 from zope.app.testing.dochttp import dochttp
 import transaction
-from zope.app.testing.functional import SampleFunctionalTest
-from zope.app.testing.functional import BrowserTestCase, HTTPTestCase
+from zope.app.testing.functional import SampleFunctionalTest, BrowserTestCase
 from zope.app.testing.functional import FunctionalDocFileSuite
 from zope.app.testing.functional import FunctionalTestCase
 from zope.app.testing.functional import FunctionalTestSetup
@@ -41,6 +40,7 @@ from zope.app.testing.testing import AppTestingLayer
 from zope.app.testing.testing import FailingKlass
 
 
+
 HEADERS = """\
 HTTP/1.1 200 OK
 Content-Type: text/plain
@@ -219,9 +219,9 @@ class CookieHandlerTestCase(unittest.TestCase):
         self.handler.saveCookies(response)
         self.assertEqual(len(self.handler.cookies), 2)
         self.assert_(self.handler.cookies['spam'].OutputString() in
-                         ('spam=eggs; Path=/foo;', 'spam=eggs; Path=/foo'))
+                         ('spam=eggs; Path=/foo;','spam=eggs; Path=/foo'))
         self.assert_(self.handler.cookies['monty'].OutputString() in
-                         ('monty=python;', 'monty=python'))
+                         ('monty=python;','monty=python'))
 
     def test_httpCookie(self):
         cookies = self.handler.cookies
@@ -246,33 +246,6 @@ class CookieHandlerTestCase(unittest.TestCase):
     # standard library has tests for (we hope).
 
 
-class HTTPFunctionalTest(HTTPTestCase):
-
-    def testNoDefaultReferer(self):
-        # There should be no referer set in the request by default.
-        r = self.makeRequest()
-        self.assertRaises(KeyError, r.environment.__getitem__, 'HTTP_REFERER')
-
-
-class BrowserFunctionalTest(BrowserTestCase):
-
-    def testNoDefaultReferer(self):
-        # There should be no referer set in the request by default.
-        r = self.makeRequest()
-        self.assertRaises(KeyError, r.environment.__getitem__, 'HTTP_REFERER')
-
-
-class HTTPCallerFunctionalTest(FunctionalTestCase):
-
-    def testNoDefaultReferer(self):
-        # There should be no referer set in the request by default.
-        from zope.app.testing.functional import HTTPCaller
-        http = HTTPCaller()
-        response = http("GET /++skin++Basic HTTP/1.1\n\n")
-        self.assertRaises(KeyError, response._request.environment.__getitem__,
-                          'HTTP_REFERER')
-
-
 class GetCookies(object):
     """Get all cookies set."""
 
@@ -308,7 +281,8 @@ class CookieFunctionalTest(BrowserTestCase):
         super(CookieFunctionalTest, self).setUp()
         self.assertEqual(
                 len(self.cookies.keys()), 0,
-                'cookies store should be empty')
+                'cookies store should be empty'
+                )
 
         zope.configuration.xmlconfig.string(r'''
         <configure xmlns="http://namespaces.zope.org/browser">
@@ -350,16 +324,16 @@ class CookieFunctionalTest(BrowserTestCase):
         response = self.publish('/')
 
         self.assertEquals(response.getStatus(), 200)
-        self.assert_('aid' not in response._request._cookies)
+        self.assert_(not response._request._cookies.has_key('aid'))
         self.assertEquals(response._request._cookies['bid'], 'bval')
 
     def testHttpCookieHeader(self):
         # Passing an HTTP_COOKIE header to publish adds cookies
         response = self.publish('/', env={
-            'HTTP_COOKIE':
-                '$Version=1, aid=aval; $Path=/sub/folder, bid=bval'})
+            'HTTP_COOKIE': '$Version=1, aid=aval; $Path=/sub/folder, bid=bval'
+            })
         self.assertEquals(response.getStatus(), 200)
-        self.failIf('aid' in response._request._cookies)
+        self.failIf(response._request._cookies.has_key('aid'))
         self.assertEquals(response._request._cookies['bid'], 'bval')
 
     def testStickyCookies(self):
@@ -389,7 +363,6 @@ class SkinsAndHTTPCaller(FunctionalTestCase):
         response = http("GET /++skin++Basic HTTP/1.1\n\n")
         self.assert_("zopetopBasic.css" in str(response))
 
-
 class RetryProblemFunctional(FunctionalTestCase):
 
     def setUp(self):
@@ -418,7 +391,6 @@ Authorization: Basic mgr:mgrpw
         self.assertNotEqual(response.getStatus(), 599)
         self.assertEqual(response.getStatus(), 500)
 
-
 class RetryProblemBrowser(BrowserTestCase):
     def setUp(self):
         super(RetryProblemBrowser, self).setUp()
@@ -443,7 +415,6 @@ class RetryProblemBrowser(BrowserTestCase):
 
 ftesting_zcml = os.path.join(here, 'ftesting.zcml')
 
-
 def doctest_FunctionalTestSetup_clears_global_utilities():
     """Test that FunctionalTestSetup doesn't leave global utilities.
 
@@ -484,7 +455,6 @@ def doctest_FunctionalTestSetup_clears_global_utilities():
 
 empty_zcml = os.path.join(here, 'empty.zcml')
 
-
 def doctest_FunctionalTestSetup_supports_product_config():
     """Test that FunctionalTestSetup configures products.
 
@@ -639,15 +609,13 @@ def doctest_ZCMLLayer_carries_product_configuration():
 
 def test_suite():
     checker = RENormalizing([
-        (re.compile(r'^HTTP/1.1 (\d{3}) .*?\n'), 'HTTP/1.1 \\1\n')])
+        (re.compile(r'^HTTP/1.1 (\d{3}) .*?\n'), 'HTTP/1.1 \\1\n')
+        ])
     SampleFunctionalTest.layer = AppTestingLayer
     CookieFunctionalTest.layer = AppTestingLayer
     SkinsAndHTTPCaller.layer = AppTestingLayer
     RetryProblemFunctional.layer = AppTestingLayer
     RetryProblemBrowser.layer = AppTestingLayer
-    HTTPFunctionalTest.layer = AppTestingLayer
-    BrowserFunctionalTest.layer = AppTestingLayer
-    HTTPCallerFunctionalTest.layer = AppTestingLayer
 
     doc_test = FunctionalDocFileSuite('doctest.txt', 'cookieTestOne.txt',
         'cookieTestTwo.txt', checker=checker)
@@ -660,9 +628,6 @@ def test_suite():
         unittest.makeSuite(CookieHandlerTestCase),
         DocTestSuite(),
         unittest.makeSuite(SampleFunctionalTest),
-        unittest.makeSuite(HTTPFunctionalTest),
-        unittest.makeSuite(BrowserFunctionalTest),
-        unittest.makeSuite(HTTPCallerFunctionalTest),
         unittest.makeSuite(CookieFunctionalTest),
         unittest.makeSuite(SkinsAndHTTPCaller),
         unittest.makeSuite(RetryProblemFunctional),
